<template>
  <div class="barchar"
       ref="chart"></div>
</template>

<script>
import * as echarts from "echarts"
import {
  countCountryDimension,
  countProvinceDimension,
  countZhPipeStations,
} from "@/api/screen.js"
export default {
  props: {
    width: {
      type: String,
      default: "100%",
    },
    height: {
      type: String,
      default: "100%",
    },
    autoResize: {
      type: Boolean,
      default: true,
    },
    // option: {
    //   type: Object,
    //   required: true
    // },
    type: {
      type: String,
      default: "canvas",
    },
    project: {
      type: String,
      default: "全国项目",
    },
    title: {
      type: String,
      default: "",
    },
  },
  data () {
    return {
      chart: null,
      dataList: [],
    }
  },
  computed: {
    option () {
      let data=[
        {
          country: "苏丹",
          count: 1,
        },
        {
          country: "印度尼西亚",
          count: 1,
        },
        {
          country: "阿联酋",
          count: 1,
        },
        {
          country: "乌兹别克斯坦",
          count: 1,
        },
        {
          country: "哈萨克斯坦",
          count: 2,
        },
        {
          country: "委内瑞拉",
          count: 1,
        },
        {
          country: "斯里兰卡",
          count: 1,
        },
        {
          country: "中国",
          count: 17,
        },
        {
          country: "其他",
          count: 1,
        },
        {
          country: "土库曼斯坦",
          count: 1,
        },
        {
          country: "新加坡",
          count: 1,
        },
      ]

      let xAxisData=[]
      let yAxisData=[]
      if(this.dataList) {
        data=this.dataList
      }
      let count=0
      let countVal=0

      const title=this.title
      data.forEach(item => {
        let name=item.province||item.country||item.输送介质
        let value=item.count||item.站场数量
        if(title=="站场座数"&&item.管道数量) {
          count+=item.管道数量
        } else {
          count+=item.count||0
        }

        // switch (title) {
        //   case "站场座数":
        //     countVal = item.管道数量
        //     break
        //   case "项目个数":
        //     countVal = item.count
        //     break
        // }

        xAxisData.push(name)
        yAxisData.push(value)
      })

      var obj=[];
      for(var i in xAxisData) {
        if(xAxisData[i]) {
          obj.push(xAxisData[i])
        } else {
          obj.push("其他")
        }
      }

      xAxisData=obj

      if(typeof count==="number") {
        this.$bus.$emit("changeCount",count)
      }
      let option={
        backgroundColor: "transparent",
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "shadow",
          },
        },
        grid: {
          top: "12%",
          right: "0%",
          left: "0%",
          bottom: "13%",
          containLabel: true,
        },
        xAxis: [
          {
            type: "category",
            data: xAxisData,
            axisLine: {
              lineStyle: {
                color: "rgba(255,255,255,0.12)",
              },
            },
            interval: 0,
            axisLabel: {
              margin: 10,
              color: "#e2e9ff",
              textStyle: {
                fontSize: 11,
              },
              formatter: function(value) {
                //
                var ret="" //拼接加\n返回的类目项
                var maxLength=2 //每项显示文字个数
                var valLength=value.length //X轴类目项的文字个数
                var rowN=Math.ceil(valLength/maxLength) //类目项需要换行的行数
                if(xAxisData.length<7) {
                  return value
                }
                if(rowN>1) {
                  //如果类目项的文字大于3,
                  for(var i=0;i<rowN;i++) {
                    var temp="" //每次截取的字符串
                    var start=i*maxLength //开始截取的位置
                    var end=start+maxLength //结束截取的位置
                    //这里也可以加一个是否是最后一行的判断，但是不加也没有影响，那就不加吧
                    temp=value.substring(start,end)+"\n"
                    ret+=temp //凭借最终的字符串
                  }
                  return ret
                } else {
                  return value
                }
              },
            },
          },
        ],
        yAxis: [
          {
            axisLabel: {
              formatter: "{value}",
              color: "#e2e9ff",
            },
            axisLine: {
              show: false,
            },
            splitLine: {
              lineStyle: {
                color: "rgba(255,255,255,0.12)",
              },
            },
          },
        ],
        series: [
          {
            name: this.title,
            type: "bar",
            data: yAxisData,
            barWidth: "12px",
            itemStyle: {
              normal: {
                color: new echarts.graphic.LinearGradient(
                  0,
                  0,
                  0,
                  1,
                  [
                    {
                      offset: 0,
                      color: "rgba(0,244,255,1)", // 0% 处的颜色
                    },
                    {
                      offset: 1,
                      color: "rgba(0,77,167,1)", // 100% 处的颜色
                    },
                  ],
                  false
                ),
                barBorderRadius: [20,20,0,0],
                shadowColor: "rgba(0,160,221,1)",
                shadowBlur: 4,
              },
            },
            label: {
              normal: {
                show: true,
                lineHeight: 14,
                width: 40,
                height: 14,
                backgroundColor: "rgba(0,160,221,0.1)",
                borderRadius: 200,
                position: ["-8","-20"],
                distance: 1,
                formatter: value => {
                  // console.log(value);
                  if(value.name=="中国") {
                    return [
                      `    {d|●}", " {a|${value.value}}     \n", "    {b|}`,
                    ].join(",")
                  }
                },
                // formatter: ["    {d|●}", " {a|{c}}     \n", "    {b|}"].join(
                //   ","
                // ),
                rich: {
                  d: {
                    color: "#3CDDCF",
                  },
                  a: {
                    color: "#fff",
                    align: "center",
                  },
                  b: {
                    width: 1,
                    height: 15,
                    borderWidth: 1,
                    borderColor: "#234e6c",
                    align: "left",
                  },
                },
              },
            },
          },
        ],
      }

      return option
    },
  },
  watch: {
    option: {
      deep: true,
      handler (newVal) {
        this.setOptions(newVal)
      },
    },
    project: {
      deep: true,
      immediate: true,
      handler (newVal) {
        let requsetFn=null
        switch(newVal) {
          case "全球项目":
            requsetFn=countCountryDimension
            break
          case "全国项目":
            requsetFn=countProvinceDimension
            break
          case "全球管网图":
            requsetFn=countZhPipeStations
            break
          case "全国管网图":
            requsetFn=countZhPipeStations
            break
          default:
            break
        }
        requsetFn&&this.initData(requsetFn)
        this.setOptions(this.option)
      },
    },
  },
  mounted () {
    // this.initData()
    this.initChart()
    if(this.autoResize) {
      window.addEventListener("resize",this.resizeHandler)
    }
  },
  beforeDestroy () {
    if(!this.chart) {
      return
    }
    if(this.autoResize) {
      window.removeEventListener("resize",this.resizeHandler)
    }
    this.chart.dispose()
    this.chart=null
  },
  methods: {
    resizeHandler () {
      this.chart&&this.chart.resize()
    },
    initChart () {
      this.chart=echarts.init(this.$refs.chart,"",{
        renderer: this.type,
      })
      this.chart.setOption(this.option)
      this.chart.on("click",this.handleClick)
    },
    handleClick (params) {
      this.$emit("click",params)
    },
    setOptions (option) {
      this.clearChart()
      this.resizeHandler()
      if(this.chart) {
        this.chart.setOption(option)
      }
    },
    refresh () {
      this.setOptions(this.option)
    },
    clearChart () {
      this.chart&&this.chart.clear()
    },
    async initData (requsetFn=countCountryDimension) {
      const res=await requsetFn()
      if(res.code==200) {
        this.dataList=res.result
        console.log("requsetFn",res)
      }
    },
  },
}
</script>

<style lang="scss" scoped>
.barchar {
  width: 100%;
  height: 100%;
}
</style>
